/* Bluefish HTML Editor
 * pixmap.h
 *
 * Copyright (C) 2002 Oliver Sessink
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

GtkWidget *new_pixmap(gint type);
void set_default_icon(void);

extern const guint8 pixmap_edit_tag[];
extern const guint8 pixmap_abbr[];
extern const guint8 pixmap_acronym[];
extern const guint8 pixmap_anchor[];
extern const guint8 pixmap_bluefish_icon1[];
extern const guint8 pixmap_body[];
extern const guint8 pixmap_bold[];
extern const guint8 pixmap_bookmarks[];
extern const guint8 pixmap_brbreak[];
extern const guint8 pixmap_breakall[];
extern const guint8 pixmap_center[];
extern const guint8 pixmap_cite[];
extern const guint8 pixmap_close[];
extern const guint8 pixmap_code[];
extern const guint8 pixmap_color_select[];
extern const guint8 pixmap_comment[];
extern const guint8 pixmap_context[];
extern const guint8 pixmap_css_small[];
extern const guint8 pixmap_cssdiv[];
extern const guint8 pixmap_cssnewstyle[];
extern const guint8 pixmap_cssspan[];
extern const guint8 pixmap_cssstyle[];
extern const guint8 pixmap_dfn[];
extern const guint8 pixmap_email[];
extern const guint8 pixmap_embed[];
extern const guint8 pixmap_filetree[];
extern const guint8 pixmap_font[];
extern const guint8 pixmap_font_base[];
extern const guint8 pixmap_fonth1[];
extern const guint8 pixmap_fonth2[];
extern const guint8 pixmap_fonth3[];
extern const guint8 pixmap_fonth4[];
extern const guint8 pixmap_fonth5[];
extern const guint8 pixmap_fonth6[];
extern const guint8 pixmap_fontm1[];
extern const guint8 pixmap_fontp1[];
extern const guint8 pixmap_fontpre[];
extern const guint8 pixmap_fontsub[];
extern const guint8 pixmap_fontsuper[];
extern const guint8 pixmap_form[];
extern const guint8 pixmap_form_check[];
extern const guint8 pixmap_form_hidden[];
extern const guint8 pixmap_form_option[];
extern const guint8 pixmap_form_radio[];
extern const guint8 pixmap_form_select[];
extern const guint8 pixmap_form_submit[];
extern const guint8 pixmap_form_text[];
extern const guint8 pixmap_form_textarea[];
extern const guint8 pixmap_form_optiongroup[];
extern const guint8 pixmap_frame[];
extern const guint8 pixmap_frame2[];
extern const guint8 pixmap_frame_base[];
extern const guint8 pixmap_frame_no[];
extern const guint8 pixmap_frameset[];
extern const guint8 pixmap_frameset2[];
extern const guint8 pixmap_framewhiz[];
extern const guint8 pixmap_fref[];
extern const guint8 pixmap_frdialog[];
extern const guint8 pixmap_frdialog2[];
extern const guint8 pixmap_frhide[];
extern const guint8 pixmap_frinfo[];
extern const guint8 pixmap_frsearch[];
extern const guint8 pixmap_frlibrary[];
extern const guint8 pixmap_frlibrary_ro[];
extern const guint8 pixmap_frgroup[];
extern const guint8 pixmap_frnote[];
extern const guint8 pixmap_frfunction[];
extern const guint8 pixmap_frtag[];
extern const guint8 pixmap_frvar[];
extern const guint8 pixmap_frcss[];
extern const guint8 pixmap_frsnippet[];
extern const guint8 pixmap_headings[];
extern const guint8 pixmap_hrule[];
extern const guint8 pixmap_image[];
extern const guint8 pixmap_indent[];
extern const guint8 pixmap_italic[];
extern const guint8 pixmap_kbd[];
extern const guint8 pixmap_linkstylesheet[];
extern const guint8 pixmap_list[];
extern const guint8 pixmap_list_dd[];
extern const guint8 pixmap_list_dl[];
extern const guint8 pixmap_list_dt[];
extern const guint8 pixmap_list_li[];
extern const guint8 pixmap_list_ol[];
extern const guint8 pixmap_list_ul[];
extern const guint8 pixmap_meta[];
extern const guint8 pixmap_multithumbs[];
extern const guint8 pixmap_nbsp[];
extern const guint8 pixmap_new[];
extern const guint8 pixmap_nothing[];
extern const guint8 pixmap_open_small[];
extern const guint8 pixmap_paragraph[];
extern const guint8 pixmap_php3[];
extern const guint8 pixmap_prefseditor[];
extern const guint8 pixmap_prefsfiletypes[];
extern const guint8 pixmap_prefsinterface[];
extern const guint8 pixmap_prefsexternal[];
extern const guint8 pixmap_prefshtml[];
extern const guint8 pixmap_prefsoutputparser[];
extern const guint8 pixmap_prefsfiles[];
extern const guint8 pixmap_prefsimages[];
extern const guint8 pixmap_prefssyntax[];
extern const guint8 pixmap_quick_start[];
extern const guint8 pixmap_right[];
extern const guint8 pixmap_samp[];
extern const guint8 pixmap_table[];
extern const guint8 pixmap_table2[];
extern const guint8 pixmap_table_capt[];
extern const guint8 pixmap_table_td[];
extern const guint8 pixmap_table_td2[];
extern const guint8 pixmap_table_th[];
extern const guint8 pixmap_table_th2[];
extern const guint8 pixmap_table_tr[];
extern const guint8 pixmap_table_tr2[];
extern const guint8 pixmap_tablewhiz[];
extern const guint8 pixmap_thumbnail[];
extern const guint8 pixmap_underline[];
extern const guint8 pixmap_unindent[];
extern const guint8 pixmap_var[];
extern const guint8 pixmap_view_in_browser[];
